@@ -22,7 +22,7 @@ import os
 import six
 import sys
 
-from cliff import argparse
+from cliff import _argparse
 from . import complete
 from . import help
 from . import utils
@@ -118,10 +118,10 @@ class App(object):
                     stdin = codecs.getreader(encoding)(sys.stdin)
 
                 if not (stdout or isinstance(sys.stdout, codecs.StreamWriter)):
-                    stdout = codecs.getwriter(encoding)(sys.stdout)
+                    stdout = utils.getwriter(encoding)(sys.stdout)
 
                 if not (stderr or isinstance(sys.stderr, codecs.StreamWriter)):
-                    stderr = codecs.getwriter(encoding)(sys.stderr)
+                    stderr = utils.getwriter(encoding)(sys.stderr)
 
         self.stdin = stdin or sys.stdin
         self.stdout = stdout or sys.stdout
@@ -143,7 +143,7 @@ class App(object):
         :paramtype extra_kwargs: dict
         """
         argparse_kwargs = argparse_kwargs or {}
-        parser = argparse.ArgumentParser(
+        parser = _argparse.ArgumentParser(
             description=description,
             add_help=False,
             **argparse_kwargs
